{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../../modules
    ../../users/simon
  ];

  sbruder = {
    games.enable = true;
    gui.enable = true;
    media-proxy.enable = true;
    mullvad.enable = true;
    restic.system = {
      enable = true;
      extraPaths = [
        "/data"
      ];
    };
    unfree.allowSoftware = true;
    wireguard.home.enable = true;
  };

  virtualisation.libvirtd.enable = true;

  services.tor = {
    enable = true;
    client.enable = true;
  };
  services.privoxy = {
    enable = true;
    enableTor = true;
  };

  networking.hostName = "sayuri";

  system.stateVersion = "20.03";

  specialisation = {
    foldingathome.configuration = {
      services.foldingathome = {
        enable = true;
        user = "sbruder";
      };
    };
    intel-sucks.configuration = {
      # https://make-linux-fast-again.com/
      boot.kernelParams = [
        "l1tf=off"
        "mds=off"
        "mitigations=off"
        "no_stf_barrier"
        "noibpb"
        "noibrs"
        "nopti"
        "nospec_store_bypass_disable"
        "nospectre_v1"
        "nospectre_v2"
        "tsx=on"
        "tsx_async_abort=off"
      ];
      sbruder.gui.enable = lib.mkForce false;
    };
  };
}
